<?php
/**
 * @file
 * Theme functions for the Pirobox module.
 */

/**
 * Returns HTML for an Pirobox image field formatter.
 *
 * @param $variables
 *   An associative array containing:
 *   - item: An array of image data.
 *   - image_style: An optional image style.
 *   - path: An array containing the link 'path' and link 'options'.
 *
 * @ingroup themeable
 */
function theme_pirobox_formatter($variables) {
  $settings = $variables['display_settings'];
  $gallery_id = '';
  $unique = FALSE;
  
  switch ($variables['entity_type']) {
    case 'node':
      // Build the gallery id.
      $nid = !empty($variables['entity']->nid) ? $variables['entity']->nid : 'nid';
      
      switch ($settings['pirobox_gallery']) {
        case 'post':
          $gallery_id = 'gallery-' . $nid;
          break;
        case 'page':
          $gallery_id = 'gallery-all';
          break;
        case 'field_post':
          $gallery_id = 'gallery-' . $nid . '-' . $variables['field']['field_name'];
          break;
        case 'field_page':
          $gallery_id = 'gallery-' . $variables['field']['field_name'];
          break;
        case 'post_user':
          $gallery_id = 'gallery-' . $nid . '-user-' . $variables['entity']->uid;
          break;
        case 'page_user':
          $gallery_id = 'gallery-user-' . $variables['entity']->uid . '-all';
          break;
        case 'custom':
          $gallery_id = check_plain($settings['pirobox_gallery_custom']);
          break;
        case 'none':
          $gallery_id = '';
          $unique = TRUE;
      }
      
      switch ($settings['pirobox_caption']) {
        case 'auto':
          // If the title is empty use alt or the entity title in that order.
          if (!empty($variables['item']['title'])) {
            $caption = $variables['item']['title'];
          }
          elseif (!empty($variables['item']['alt'])) {
            $caption = $variables['item']['alt'];
          }
          elseif (!empty($variables['entity']->title)) {
            $caption = $variables['entity']->title;
          }
          else {
            $caption = $variables['item']['filename'];
          }
          break;

        case 'title':
          $caption = isset($variables['item']['title']) ? $variables['item']['title'] : check_plain($variables['entity']->title);
          break;
        case 'alt':
          $caption = isset($variables['item']['alt']) ? $variables['item']['alt'] : check_plain($variables['entity']->title);
          break;
        case 'entity_title':
          $caption = check_plain($variables['entity']->title);
          break;
        default:
          $caption = $variables['item']['filename'];
      }
      break;

    case 'comment':
      // Build the gallery id.
      $cid = !empty($variables['entity']->cid) ? $variables['entity']->cid : 'cid';
      
      switch ($settings['pirobox_gallery']) {
        case 'comment':
          $gallery_id = 'gallery-comment-' . $cid;
          break;
        case 'page':
          $gallery_id = 'gallery-all';
          break;
        case 'custom':
          $gallery_id = check_plain($settings['pirobox_gallery_custom']);
          break;
        case 'none':
          $gallery_id = '';
          $unique = TRUE;
      }
      
      switch ($settings['pirobox_caption']) {
        case 'auto':
          // If the title is empty use alt or the entity title in that order.
          if (!empty($variables['item']['title'])) {
            $caption = check_plain($variables['item']['title']);
          }
          elseif (!empty($variables['item']['alt'])) {
            $caption = check_plain($variables['item']['alt']);
          }
          elseif (!empty($variables['entity']->subject)) {
            $caption = check_plain($variables['entity']->subject);
          }
          else {
            $caption = $variables['item']['filename'];
          }
          break;

        case 'title':
          $caption = isset($variables['item']['title']) ? $variables['item']['title'] : check_plain($variables['entity']->subject);
          break;
        case 'alt':
          $caption = isset($variables['item']['alt']) ? $variables['item']['alt'] : check_plain($variables['entity']->subject);
          break;
        case 'entity_title':
          $caption = check_plain($variables['entity']->subject);
          break;
        default:
          $caption = $variables['item']['filename'];
      }
      break;

    case 'taxonomy_term':
      // Build the gallery id.
      $tid = !empty($variables['entity']->tid) ? $variables['entity']->tid : 'term';
      
      switch ($settings['pirobox_gallery']) {
        case 'term':
          $gallery_id = 'gallery-term-' . $tid;
          break;
        case 'page':
          $gallery_id = 'gallery-all';
          break;
        case 'custom':
          $gallery_id = check_plain($settings['pirobox_gallery_custom']);
          break;
        case 'none':
          $gallery_id = '';
          $unique = TRUE;
      }
      
      switch ($settings['pirobox_caption']) {
        case 'auto':
          // If the title is empty use alt or the entity title in that order.
          if (!empty($variables['item']['title'])) {
            $caption = check_plain($variables['item']['title']);
          }
          elseif (!empty($variables['item']['alt'])) {
            $caption = check_plain($variables['item']['alt']);
          }
          elseif (!empty($variables['entity']->name)) {
            $caption = check_plain($variables['entity']->name);
          }
          else {
            $caption = $variables['item']['filename'];
          }
          break;

        case 'title':
          $caption = isset($variables['item']['title']) ? $variables['item']['title'] : check_plain($variables['entity']->name);
          break;
        case 'alt':
          $caption = isset($variables['item']['alt']) ? $variables['item']['alt'] : check_plain($variables['entity']->name);
          break;
        case 'entity_title':
          $caption = check_plain($variables['entity']->name);
          break;
        default:
          $caption = $variables['item']['filename'];
      }
      break;
  }

  /**
   * Media module supports no image title and image alt. *
   * 
   * @todo Check Media module new versions for added alt and title.
   */
  $image = array(
    'path' => $variables['item']['uri'],
    'alt' => isset($variables['item']['alt']) ? $variables['item']['alt'] : '', // *
    'title' => isset($variables['item']['title']) ? $variables['item']['title'] : '', // *
    'style_name' => $settings['pirobox_entity_style'],
  );

  if (isset($variables['item']['width']) && isset($variables['item']['height'])) {
    $image['width'] = $variables['item']['width'];
    $image['height'] = $variables['item']['height'];
  }

  // Shorten the caption for the example styles or when caption shortening is active.
  $pirobox_style = variable_get('pirobox_style', 'default');
  $trim_length = variable_get('pirobox_caption_trim_length', 75);
  if ((variable_get('pirobox_caption_trim', 0)) && (drupal_strlen($caption) > $trim_length)) {
    $caption = drupal_substr($caption, 0, $trim_length - 5) . '...';
  }

  if ($style_name = $settings['pirobox_image_style']) {
    $path = image_style_url($style_name, $image['path']);
  }
  else {
    $path = file_create_url($image['path']);
  }

  return theme('pirobox_imagefield', array('image' => $image, 'path' => $path, 'title' => $caption, 'gid' => $gallery_id, 'unique' => $unique));
}

/**
 * Returns HTML for an image using a specific Pirobox image style.
 *
 * @param $variables
 *   An associative array containing:
 *   - image: image item as array.
 *   - path: The path of the image that should be displayed in the Pirobox.
 *   - title: The title text that will be used as a caption in the Pirobox.
 *   - gid: Gallery id for Pirobox image grouping.
 *
 * @ingroup themeable
 */
function theme_pirobox_imagefield($variables) {
  if ($variables['unique'] == FALSE) {
    $class = array('pirobox-' . $variables['gid']);
  }
  if ($variables['unique'] == TRUE) {
    $class = array('pirobox-' . rand());
  }

  if ($variables['image']['style_name'] == 'hide') {
    $image = '';
    $class[] = 'js-hide';
  }
  elseif (!empty($variables['image']['style_name'])) {
    $image = theme('image_style', $variables['image']);
  }
  else {
    $image = theme('image', $variables['image']);
  }

  $options = array(
    'html' => TRUE,
    'attributes' => array(
      'title' => $variables['title'],
      'class' => implode(' ', $class)
    )
  );

  return l($image, $variables['path'], $options);
}
